# IMPORTANT

This is a pre-release. Please do not use it in production.

We have requested permission from the Pulumi team to start working on porting (or bridging) the Terraform Databricks provider to Pulumi.

This release matches version 0.4.0 of the Terraform Databricks provider.
